@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -84,7 +81,6 @@ class eop_eps               : public eop_core<eop_eps>               {};
 class eop_abs               : public eop_core<eop_abs>               {};
 class eop_conj              : public eop_core<eop_conj>              {};
 class eop_pow               : public eop_core<eop_pow>               {};
-class eop_pow_int           : public eop_core<eop_pow_int>           {};
 class eop_randu             : public eop_core<eop_randu>             {};
 class eop_randn             : public eop_core<eop_randn>             {};
 class eop_zeros             : public eop_core<eop_zeros>             {};
