@@ -1,9 +1,6 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
-// - Ian Cullinan (ian dot cullinan at nicta dot com dot au)
+// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2009-2010 Ian Cullinan
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -1721,6 +1718,8 @@ field_aux::save(const field< std::string >& x, const std::string& name, const fi
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(type);
+  
   err_msg.clear();
   
   return diskio::save_std_string(x, name);
@@ -1734,6 +1733,8 @@ field_aux::save(const field< std::string >& x, std::ostream& os, const file_type
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(type);
+  
   err_msg.clear();
   
   return diskio::save_std_string(x, os);
@@ -1747,6 +1748,8 @@ field_aux::load(field< std::string >& x, const std::string& name, const file_typ
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(type);
+  
   return diskio::load_std_string(x, name, err_msg);
   }
 
@@ -1758,6 +1761,8 @@ field_aux::load(field< std::string >& x, std::istream& is, const file_type type,
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(type);
+  
   return diskio::load_std_string(x, is, err_msg);
   }
 
