@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -22,7 +19,11 @@ template<typename T1, typename T2>
 arma_inline
 arma_warn_unused
 typename T1::elem_type
-dot(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,T2>& B)
+dot
+  (
+  const Base<typename T1::elem_type,T1>& A,
+  const Base<typename T1::elem_type,T2>& B
+  )
   {
   arma_extra_debug_sigprint();
   
@@ -35,7 +36,12 @@ template<typename T1, typename T2>
 arma_inline
 arma_warn_unused
 typename T1::elem_type
-norm_dot(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,T2>& B)
+norm_dot
+  (
+  const Base<typename T1::elem_type,T1>& A, 
+  const Base<typename T1::elem_type,T2>& B,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
   {
   arma_extra_debug_sigprint();
   
