@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -36,6 +33,8 @@ linspace
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   arma_debug_check( (num < 2), "linspace(): num must be >= 2");
   
   typedef typename vec_type::elem_type eT;
@@ -413,6 +412,8 @@ abs(const Base<typename T1::elem_type,T1>& X, const typename arma_not_cx<typenam
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return eOp<T1, eop_abs>(X.get_ref());
   }
 
@@ -425,6 +426,8 @@ abs(const BaseCube<typename T1::elem_type,T1>& X, const typename arma_not_cx<typ
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return eOpCube<T1, eop_abs>(X.get_ref());
   }
 
@@ -437,6 +440,8 @@ abs(const Base<std::complex<typename T1::pod_type>, T1>& X, const typename arma_
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return mtOp<typename T1::pod_type, T1, op_abs>( X.get_ref() );
   }
 
@@ -449,6 +454,8 @@ abs(const BaseCube< std::complex<typename T1::pod_type>,T1>& X, const typename a
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return mtOpCube<typename T1::pod_type, T1, op_abs>( X.get_ref() );
   }
 
@@ -464,6 +471,8 @@ fabs(const Base<typename T1::pod_type,T1>& X, const typename arma_not_cx<typenam
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return eOp<T1, eop_abs>(X.get_ref());
   }
 
@@ -476,6 +485,8 @@ fabs(const BaseCube<typename T1::pod_type,T1>& X, const typename arma_not_cx<typ
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return eOpCube<T1, eop_abs>(X.get_ref());
   }
 
@@ -488,6 +499,8 @@ fabs(const Base<std::complex<typename T1::pod_type>, T1>& X, const typename arma
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return mtOp<typename T1::pod_type, T1, op_abs>( X.get_ref() );
   }
 
@@ -500,6 +513,8 @@ fabs(const BaseCube< std::complex<typename T1::pod_type>,T1>& X, const typename
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   return abs(X);
   }
 
@@ -706,51 +721,4 @@ pow(const BaseCube<typename T1::elem_type,T1>& A, const typename T1::elem_type::
 
 
 
-// #if defined(ARMA_GOOD_COMPILER)
-// 
-// 
-// // pow_s32  (integer exponent)
-// 
-// template<typename T1>
-// arma_inline
-// const eOp<T1, eop_pow_int>
-// pow(const Base<typename T1::elem_type,T1>& A, const int exponent)
-//   {
-//   arma_extra_debug_sigprint();
-//   
-//   if(exponent >= 0)
-//     {
-//     return eOp<T1, eop_pow_int>(A.get_ref(), exponent, 0);
-//     }
-//   else
-//     {
-//     return eOp<T1, eop_pow_int>(A.get_ref(), -exponent, 1);
-//     }
-//   }
-// 
-// 
-// 
-// template<typename T1>
-// arma_inline
-// const eOpCube<T1, eop_pow_int>
-// pow(const BaseCube<typename T1::elem_type,T1>& A, const int exponent)
-//   {
-//   arma_extra_debug_sigprint();
-//   
-//   if(exponent >= 0)
-//     {
-//     return eOpCube<T1, eop_pow_int>(A.get_ref(),  exponent, 0);
-//     }
-//   else
-//     {
-//     return eOpCube<T1, eop_pow_int>(A.get_ref(), -exponent, 1);
-//     }
-//   }
-// 
-// 
-// 
-// #endif
-
-
-
 //! @}
