@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -38,6 +35,8 @@ ones(const u32 n_elem, const typename arma_Mat_Col_Row_only<vec_type>::result* j
   {
   arma_extra_debug_sigprint();
   
+  arma_ignore(junk);
+  
   if(is_Row<vec_type>::value == true)
     {
     return eOp<vec_type, eop_ones_full>(1, n_elem);
@@ -69,7 +68,7 @@ ones(const u32 n_rows, const u32 n_cols, const typename arma_Mat_Col_Row_only<ma
   {
   arma_extra_debug_sigprint();
   
-  arma_type_check<is_Mat<mat_type>::value == false>::apply();
+  arma_ignore(junk);
   
   return eOp<mat_type, eop_ones_full>(n_rows, n_cols);
   }
@@ -94,7 +93,7 @@ ones(const u32 n_rows, const u32 n_cols, const u32 n_slices, const typename arma
   {
   arma_extra_debug_sigprint();
   
-  arma_type_check<is_Cube<cube_type>::value == false>::apply();
+  arma_ignore(junk);
   
   return eOpCube<cube_type, eop_ones_full>(n_rows, n_cols, n_slices);
   }
@@ -121,7 +120,7 @@ eye(const u32 n_rows, const u32 n_cols, const typename arma_Mat_Col_Row_only<mat
   {
   arma_extra_debug_sigprint();
   
-  arma_type_check<is_Mat_only<mat_type>::value == false>::apply();
+  arma_ignore(junk);
   
   return eOp<mat_type, eop_ones_diag>(n_rows, n_cols);
   }
