@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -163,6 +160,18 @@ podarray<eT>::set_size(const u32 new_n_elem)
 
 
 
+template<typename eT>
+inline
+void
+podarray<eT>::reset()
+  {
+  arma_extra_debug_sigprint();
+  
+  init(0);
+  }
+
+
+
 template<typename eT>
 inline
 void
